@@ -25,11 +25,33 @@ def pyconwaysgame():
     try:
         if compute_args().update:
             update()
-            exit()   
-        show_death = compute_args().deaths     
+            exit()  
+        if compute_args().grid:
+            fileObj = open(compute_args().grid, "r") 
+            words = fileObj.read().splitlines()
+            fileObj.close()
+            tab=[]
+            for line in words:
+                if not re.match("^[0|1|2]+$",line):
+                    print("grid must be contain only or 0")
+                    exit()
+                tab.append(list(line))    
+            for i in range(len(tab)):
+                if len(tab[i])!=len(tab[0]):
+                    print("invalid grid, must be rectangular")
+                    exit()
+                for j in range(len(tab[0])):
+                    tab[i][j]=int(tab[i][j])
+            if len(tab)<5 or len(tab)>200 or len(tab[0])<5 or len(tab[0])>200:
+                print("must be in 5-200*5-200")
+                exit()
+
+        show_death = compute_args().deaths
+        ball_mode = compute_args().ball     
         speed = compute_args().speed
         bad_param=False
         manual=False
+        generation=0
         if speed<0 or speed>10:
             print("invalid value for speed, speed should be in 0-10")
             bad_param=True
@@ -42,7 +64,7 @@ def pyconwaysgame():
             print("invalid value for columns, columns should be in 5-200")
             bad_param=True    
         ratio = compute_args().ratio
-        if ratio<0 or columns>100:
+        if ratio<0 or ratio>100:
             print("invalid value for ratio, ratio should be in 0-100")
             bad_param=True
 
@@ -71,16 +93,16 @@ def pyconwaysgame():
                 print("invalid format for born, should be x-y with 0<=x<=8 and 0<=y<=8 ")
                 bad_param=True                              
         if bad_param:
-            print("use pyconwaysgame -h to see correct options")
+            print("use pyconwaysgame -h to see correct optionsver")
             exit(1)
         if compute_args().speed == 0:
             manual=True
-
-        rows, cols =(lines, columns)
-        tab = [[0 for i in range(cols)] for j in range(rows)]
-        for i in range(rows):
-            for j in range(cols):
-                tab[i][j]=1 if random.randint(0,100)<=ratio else 0
+        if not compute_args().grid:
+            rows, cols =(lines, columns)
+            tab = [[0 for i in range(cols)] for j in range(rows)]
+            for i in range(rows):
+                for j in range(cols):
+                    tab[i][j]=1 if random.randint(0,100)<=ratio else 0
         
         while True:
             
@@ -95,6 +117,8 @@ def pyconwaysgame():
             table = columnar(data, no_borders=False, wrap_max=0,patterns=patterns,justify='c') 
             os.system('clear')
             print(table)
+            print("generation number : " + str(generation))
+            
             print("press ctrl-c to safe exit")
             if manual:
                 input("pause")
@@ -103,7 +127,7 @@ def pyconwaysgame():
             new_tab=copy.deepcopy(tab)    
             for i in range(len(tab)):
                 for j in range(len(tab[0])):
-                    nb_vivantes = count_voisins(tab, i, j)  
+                    nb_vivantes = count_voisins(tab, i, j,ball_mode)  
                     if tab[i][j]==1:
                         if nb_vivantes<int(min_to_life) or nb_vivantes>int(max_to_life):
                             new_tab[i][j]=2
@@ -112,7 +136,8 @@ def pyconwaysgame():
                             new_tab[i][j]=1
                         else:
                             new_tab[i][j]=0                         
-            tab=copy.deepcopy(new_tab)    
+            tab=copy.deepcopy(new_tab)
+            generation = generation +1    
 
     except KeyboardInterrupt:
         print("onway's game was interrupted by the user. bye!")
@@ -121,24 +146,42 @@ def pyconwaysgame():
 
 
 
-def count_voisins(tab, i, j):
+def count_voisins(tab, i, j,ball_mode):
     nb_vivantes=0
-    if i>0 and j>0 and tab[i-1][j-1]==1:
-        nb_vivantes=nb_vivantes+1
-    if i>0 and tab[i-1][j]==1:
-        nb_vivantes=nb_vivantes+1
-    if j>0 and tab[i][j-1]==1:
-        nb_vivantes=nb_vivantes+1
-    if i<len(tab)-1 and tab[i+1][j]==1:
-        nb_vivantes=nb_vivantes+1
-    if j<len(tab[0])-1 and tab[i][j+1]==1:
-        nb_vivantes=nb_vivantes+1 
-    if i>0 and j<len(tab[0])-1 and tab[i-1][j+1]==1:
-        nb_vivantes=nb_vivantes+1
-    if i<len(tab)-1 and j<len(tab[0])-1 and tab[i+1][j+1]==1:
-        nb_vivantes=nb_vivantes+1 
-    if i<len(tab)-1 and j>0 and tab[i+1][j-1]==1:
-        nb_vivantes=nb_vivantes+1
+    if not ball_mode:
+        if i>0 and j>0 and tab[i-1][j-1]==1:
+            nb_vivantes=nb_vivantes+1
+        if i>0 and tab[i-1][j]==1:
+            nb_vivantes=nb_vivantes+1
+        if j>0 and tab[i][j-1]==1:
+            nb_vivantes=nb_vivantes+1
+        if i<len(tab)-1 and tab[i+1][j]==1:
+            nb_vivantes=nb_vivantes+1
+        if j<len(tab[0])-1 and tab[i][j+1]==1:
+            nb_vivantes=nb_vivantes+1 
+        if i>0 and j<len(tab[0])-1 and tab[i-1][j+1]==1:
+            nb_vivantes=nb_vivantes+1
+        if i<len(tab)-1 and j<len(tab[0])-1 and tab[i+1][j+1]==1:
+            nb_vivantes=nb_vivantes+1 
+        if i<len(tab)-1 and j>0 and tab[i+1][j-1]==1:
+            nb_vivantes=nb_vivantes+1
+    else:
+        if tab[(i-1)%len(tab)][(j-1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1
+        if tab[(i-1)%len(tab)][j]==1:
+            nb_vivantes=nb_vivantes+1
+        if tab[i][(j-1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1
+        if tab[(i+1)%len(tab)][j]==1:
+            nb_vivantes=nb_vivantes+1
+        if tab[i][(j+1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1 
+        if tab[(i-1)%len(tab)][(j+1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1
+        if tab[(i+1)%len(tab)][(j+1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1 
+        if tab[(i+1)%len(tab)][(j-1)%len(tab[0])]==1:
+            nb_vivantes=nb_vivantes+1                
     return nb_vivantes
 
 
